hasTarget property
Whether this step has a real target widget.
When false the tooltip is positioned at the screen centre (or as
specified by TourStep.preferredPosition) and no arrow is drawn.
Implementation
final bool hasTarget;
Whether this step has a real target widget.
When false the tooltip is positioned at the screen centre (or as
specified by TourStep.preferredPosition) and no arrow is drawn.
final bool hasTarget;